==> fbp-spec-0.6.0.tgz: package/examples/index.js <==
'use strict';

var buildExampleBundle, examplesDir, getExample, listExamples, yaml;

yaml = require('js-yaml');

examplesDir = require('path').join(__dirname);

listExamples = function listExamples() {
  var f, files;
  files = require('fs').readdirSync(examplesDir);
  files = function () {
    var i, len, results1;
    results1 = [];
    for (i = 0, len = files.length; i < len; i++) {
      f = files[i];
      if (f.indexOf('.yaml') !== -1) {
        results1.push(f);
      }
    }
    return results1;
  }();
  return files;
};

getExample = function getExample(name) {
  var content, p, results;
  p = require('path').join(examplesDir, name);
  content = require('fs').readFileSync(p, {
    encoding: 'utf-8'
  });
  results = [];
  yaml.safeLoadAll(content, function (doc) {
    return results.push(doc);
  });
  if (results.length === 1) {
    results = results[0];
  }
  return results;
};

buildExampleBundle = function buildExampleBundle() {
  var contents, dest, examples, i, len, name, ref;
  examples = {};
  ref = listExamples();
  for (i = 0, len = ref.length; i < len; i++) {
    name = ref[i];
    examples[name] = getExample(name);
  }
  contents = JSON.stringify(examples, null, 2);
  dest = examplesDir + "/bundle.js";
  require('fs').writeFileSync(dest, 'window.fbpspec_examples = ' + contents + ';');
  console.log('wrote ' + dest);
  dest = examplesDir + "/bundle.json";
  require('fs').writeFileSync(dest, contents);
  return console.log('wrote ' + dest);
};

exports.bundle = buildExampleBundle;

==> fbp-spec-0.6.7.tgz: package/examples/index.js <==
"use strict";

var buildExampleBundle, examplesDir, getExample, listExamples, yaml;
yaml = require('js-yaml');
examplesDir = require('path').join(__dirname);

listExamples = function listExamples() {
  var f, files;
  files = require('fs').readdirSync(examplesDir);

  files = function () {
    var i, len, results1;
    results1 = [];

    for (i = 0, len = files.length; i < len; i++) {
      f = files[i];

      if (f.indexOf('.yaml') !== -1) {
        results1.push(f);
      }
    }

    return results1;
  }();

  return files;
};

getExample = function getExample(name) {
  var content, p, results;
  p = require('path').join(examplesDir, name);
  content = require('fs').readFileSync(p, {
    encoding: 'utf-8'
  });
  results = [];
  yaml.safeLoadAll(content, function (doc) {
    return results.push(doc);
  });

  if (results.length === 1) {
    results = results[0];
  }

  return results;
};

buildExampleBundle = function buildExampleBundle() {
  var contents, dest, examples, i, len, name, ref;
  examples = {};
  ref = listExamples();

  for (i = 0, len = ref.length; i < len; i++) {
    name = ref[i];
    examples[name] = getExample(name);
  }

  contents = JSON.stringify(examples, null, 2);
  dest = examplesDir + "/bundle.js";

  require('fs').writeFileSync(dest, "window.fbpspec_examples = ".concat(contents, ";"));

  console.log("wrote ".concat(dest));
  dest = examplesDir + "/bundle.json";

  require('fs').writeFileSync(dest, contents);

  return console.log("wrote ".concat(dest));
};

exports.bundle = buildExampleBundle;
